DataStreamConfig class

Inheritance

Constructors

DataStreamConfig({required String name, required int channels, required double sampleRate, required StreamDataType dataType, StreamParticipationMode participationMode = StreamParticipationMode.sendAllReceiveCoordinator, bool precisePolling = true})
Creates a data stream configuration. The number of channels, sample rate, and data type must be specified.

Properties

channels → int
Number of channels in the stream.
finalinherited
dataType → StreamDataType
Data type of the stream. This is a StreamDataType enum value.
finalinherited
description → String?
Returns a description of the identity.
no setteroverride
hashCode → int
The hash code for this object.
no setteroverride
id → String
Returns a unique identifier for the identity.
no setteroverride
name → String
Human-readable name for the stream.
finalinherited
participationMode → StreamParticipationMode
Defines who should participate in this data stream
final
precisePolling → bool
Whether precise polling is enabled for this data stream. i.e. with the LSL transport, it will use busy-waiting to achieve lower latency at the cost of higher CPU usage. Defaults to true.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sampleRate → double
Sample rate of the stream.
finalinherited

Methods

copyWith({String? id, String? name, int? channelCount, double? sampleRate, StreamDataType? dataType}) → NetworkStreamConfig
Creates a copy of this configuration with the given fields replaced.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts the object to a map representation for serialization.
override
toString() → String
A string representation of this object.
override
validate({bool throwOnError = false}) → bool
Validates the configuration.
inherited
validateSample(Iterable data) → void
Checks that data is a valid sample for this stream.

Operators

operator ==(Object other) → bool
The equality operator.
override