HierarchicalTopologyConfig class

Implemented types

Constructors

HierarchicalTopologyConfig({int maxNodes = 100, bool autoPromotion = true, PromotionStrategy? promotionStrategy = const PromotionStrategyFirst(), NodeConfig? defaultNodeConfig, NodeConfig? defaultCoordinatorConfig})

Properties

autoPromotion → bool
final
defaultCoordinatorConfig ↔ NodeConfig
Default configuration for the coordinator node in the topology. This node will have the coordinator role by default. It can be promoted from a regular node if needed.
latefinal
defaultNodeConfig ↔ NodeConfig
Default configuration for nodes in the topology, it is a default because node roles may change depending on the topology state. For example, a node may be promoted to a coordinator role if needed.
latefinaloverride-getter
description → String?
Returns a description of the identity.
no setteroverride
hashCode → int
The hash code for this object.
no setteroverride
id → String
Returns a unique identifier for the identity.
no setteroverride
maxNodes → int
final
name → String
Returns a human-readable name for the identity.
no setteroverride
promotionStrategy → PromotionStrategy?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? maxNodes, bool? autoPromotion, PromotionStrategy? promotionStrategy, NodeConfig? defaultNodeConfig, NodeConfig? defaultCoordinatorConfig}) → HierarchicalTopologyConfig
Creates a copy with modified values
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts the object to a map representation for serialization.
override
toString() → String
A string representation of this object.
override
validate({bool throwOnError = false}) → bool
Validates the configuration
override

Operators

operator ==(Object other) → bool
The equality operator.
override