IConfigFactory<T extends IConfig> class abstract interface

Factory interface for creating configurations.

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

defaultConfig() → T
Returns the default / basic config
fromMap(Map<String, dynamic> map) → T
Creates a config from a map
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited