Int8Mapping class
implementation of a IMessageType for int8 data.
- Inheritance
-
- Object
- MessageTypeMapping<
int> - IntMessageTypeMapping
- Int8Mapping
Constructors
- Int8Mapping({int channels = 1})
-
const
Properties
- channels → int
-
The number of channels in the stream message
final
- description → String
-
Returns a description of the identity.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Returns a unique identifier for the identity.
no setteroverride
- name → String
-
Returns a human-readable name for the identity.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → StreamDataType
-
The data type of the stream message
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
Returns a map representation of the message type mapping for
serialization.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited