ParticipantNode class

Participant nodes can produce and consume data, but cannot participate in coordination (but will receive coordination messages).

Inheritance

Constructors

ParticipantNode(NodeConfig config)

Properties

asCoordinator → CoordinatorNode
Attempts to promote the current node to a CoordinatorNode.
no setterinherited
asObserver → ObserverNode
Attempts to promote the current node to an ObserverNode.
no setterinherited
asParticipant → ParticipantNode
Attempts to promote the current node to a ParticipantNode.
no setterinherited
asRelay → RelayNode
Attempts to promote the current node to a RelayNode.
no setterinherited
asTransformer → TransformerNode
Attempts to promote the current node to a TransformerNode.
no setterinherited
capabilities → Set<NodeCapability>
Type of the node. This is a NodeCapability enum value.
no setterinherited
config → NodeConfig
Configuration for the node. This is a NodeConfig object.
finalinherited
createdAt → DateTime
no setterinherited
description → String?
Returns a description of the identity.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
id → String
Unique identifier for the node.
no setterinherited
lastSeen → DateTime
no setterinherited
metadata → Map<String, dynamic>
Returns the metadata associated with this resource.
no setterinherited
name → String
Human-readable name for the node.
no setterinherited
nodeStartedAt → DateTime?
no setterinherited
promotedAt → DateTime?
no setterinherited
role → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uId → String
Returns a unique identifier that is guaranteed to be globally unique.
no setterinherited

Methods

getMetadata(String key, {dynamic defaultValue}) → dynamic
Returns a specific metadata value by key.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
seen() → void
inherited
setMetadata(String key, dynamic value) → void
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited