PromotionStrategyFirst class

Inheritance

Constructors

PromotionStrategyFirst()
const

Properties

description → String?
Returns a description of the identity.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
id → String
Returns a unique identifier for the identity.
no setteroverride
name → String
Returns a human-readable name for the identity.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
promote(Iterable<Node> candidates) → Node
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited