StreamStopEvent class final

Command to stop a data stream.

Inheritance

Constructors

StreamStopEvent({required String streamName, required String fromNodeUId, DateTime? timestamp, String? messageId, String? parentMessageId, MessageTiming? timing})

Properties

fromNodeUId → String
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
messageId → String
finalinherited
parentMessageId → String?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
streamName → String
finalinherited
timestamp → DateTime
finalinherited
timing → MessageTiming?
How long this event's message took to reach us, as the transport measured it — see MessageTiming.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited