UserCoordinationEvent class final

User message from coordinator (broadcast to all).

Inheritance

Constructors

UserCoordinationEvent({required String messageType, required String description, required Map<String, dynamic> payload, required String fromNodeUId, String? messageId, String? parentMessageId, DateTime? timestamp, MessageTiming? timing})

Properties

description → String
finalinherited
fromNodeUId → String
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
messageId → String
finalinherited
messageType → String
finalinherited
parentMessageId → String?
finalinherited
payload → Map<String, dynamic>
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → DateTime
finalinherited
timing → MessageTiming?
How long this event's message took to reach us, as the transport measured it — see MessageTiming.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited