UserCoordinationMessage class

Inheritance

Constructors

UserCoordinationMessage({required String fromNodeUId, required String messageType, required String description, required Map<String, dynamic> payload, String? messageId, String? parentMessageId, DateTime? timestamp, Map<String, dynamic>? metadata})
UserCoordinationMessage.fromMap(Map<String, dynamic> map)
factory

Properties

description → String
final
fromNodeUId → String
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
messageId → String
finalinherited
messageType → String
final
metadata → Map<String, dynamic>
finalinherited
parentMessageId → String?
finalinherited
payload → Map<String, dynamic>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
senderClock → double?
no setterinherited
timestamp → DateTime
finalinherited
transportTiming ↔ MessageTiming?
Transport-observed timing for the message this was decoded from.
getter/setter pairinherited
type → CoordinationMessageType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
inherited
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited