generateUid function

String generateUid()

The default function to generate a unique ID. Uses the Uuid package to generate a version 4 UUID. This is a convenience function and Uuid is re-exported for direct use if needed.

Implementation

String generateUid() => _uuid.v4();