localClock static method
Returns the local clock time, used to calculate offsets.
Implementation
static double localClock() => lslLocalClockFast();
Returns the local clock time, used to calculate offsets.
static double localClock() => lslLocalClockFast();