LSLSample<T> class

A representation of a sample.

This class represents both samples pulled from an inlet, and in future versions, samples pushed to an outlet.

Constructors

LSLSample(IList<T> data, double timestamp, int errorCode)
const

Properties

data → IList<T>
final
errorCode → int
final
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
no setter
isNotEmpty → bool
no setter
length → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](int index) → T