protocolVersion property
int
get
protocolVersion
The LSL protocol version the stream info was created with (e.g. 110 for 1.10).
Implementation
int get protocolVersion => lsl_get_version(_infoBang);
The LSL protocol version the stream info was created with (e.g. 110 for 1.10).
int get protocolVersion => lsl_get_version(_infoBang);