LSLStreamProperty enum

Represents a property of an LSL stream that can be used for filtering. This enum is used in LSLStreamResolver to filter streams by their properties.

Inheritance
Available extensions

Values

name → const LSLStreamProperty
const LSLStreamProperty(lslName: 'name')
type → const LSLStreamProperty
const LSLStreamProperty(lslName: 'type')
channelCount → const LSLStreamProperty
const LSLStreamProperty(lslName: 'channel_count')
channelFormat → const LSLStreamProperty
const LSLStreamProperty(lslName: 'channel_format')
sourceId → const LSLStreamProperty
const LSLStreamProperty(lslName: 'source_id')
sampleRate → const LSLStreamProperty
const LSLStreamProperty(lslName: 'nominal_srate')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
lslName → String
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<LSLStreamProperty>
A constant List of the values in this enum, in order of their declaration.