liveNativeResolvers property

  1. @visibleForTesting
int get liveNativeResolvers

Number of native continuous resolvers created by this wrapper and not yet destroyed. Each one runs its own background resolve waves in liblsl until destroyed, so this should return to its baseline once every resolver has been destroyed.

Implementation

@visibleForTesting
static int get liveNativeResolvers => _liveNativeResolvers;