LSLTimedSample<T> class final

A sample and the local clock at the moment it was pulled.

Constructors

LSLTimedSample(IList<T> data, double timestamp, double receivedClock)
const

Properties

data → IList<T>
final
hashCode → int
The hash code for this object.
no setterinherited
receivedClock → double
lsl_local_clock() as the pull that returned this sample came back: when the sample became available to this process, not when a listener got round to it.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → double
The sample's time stamp, as LSLSample.timestamp.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited