LSLXml class

Base class for interacting with LibLSL XML elements.

This class provides low-level access to LibLSL's XML API, allowing navigation and inspection of XML nodes. Most users should use LSLXmlNode instead for a higher-level interface.

The XML structure in LibLSL follows standard XML conventions with elements that can contain text content and/or child elements.

Constructors

LSLXml({required lsl_xml_ptr xmlPtr})
Creates a new LSLXml object.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
xmlPtr → lsl_xml_ptr
The underlying LibLSL XML pointer.
final

Methods

childNamed(String name) → LSLXmlNode?
firstChild() → LSLXmlNode?
isEmpty() → bool
isText() → bool
lastChild() → LSLXmlNode?
nextSibling() → LSLXmlNode?
nextSiblingNamed(String name) → LSLXmlNode?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parent() → LSLXmlNode?
previousSibling() → LSLXmlNode?
previousSiblingNamed(String name) → LSLXmlNode?
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited