CoordinationMessageHandler class abstract
Base class for handling coordination messages
Constructors
- CoordinationMessageHandler({required CoordinationState state, required Node thisNode, required CoordinationSessionConfig sessionConfig})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionConfig → CoordinationSessionConfig
-
final
- state → CoordinationState
-
final
- thisNode → Node
-
final
Methods
-
canHandle(
CoordinationMessageType type) → bool - Check if this handler should process the given message type
-
handleMessage(
CoordinationMessage message) → Future< void> - Handle incoming coordination message
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendMessage(
CoordinationMessage message) → Future< void> - Send outgoing coordination message
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited