DataStreamConfig class
Constructors
DataStreamConfig ({required String name , required int channels , required double sampleRate , required StreamDataType dataType , StreamParticipationMode participationMode = StreamParticipationMode.sendAllReceiveCoordinator , bool precisePolling = true })
Creates a data stream configuration.
The number of channels, sample rate, and data type must be specified.
Properties
channels
→ int
Number of channels in the stream.
final inherited
dataType
→ StreamDataType
Data type of the stream.
This is a StreamDataType enum value.
final inherited
description
→ String ?
Returns a description of the identity.
no setter override
hashCode
→ int
The hash code for this object.
no setter override
id
→ String
Returns a unique identifier for the identity.
no setter override
name
→ String
Human-readable name for the stream.
final inherited
participationMode
→ StreamParticipationMode
Defines who should participate in this data stream
final
precisePolling
→ bool
Whether precise polling is enabled for this data stream.
i.e. with the LSL transport, it will use busy-waiting to achieve lower
latency at the cost of higher CPU usage.
Defaults to true.
final
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
sampleRate
→ double
Sample rate of the stream.
final inherited