- Implemented types
-
- Implementers
Properties
-
created
→ bool
-
Indicates whether the ILifecycle implementation has been created.
no setterinherited
-
description
→ String?
-
Returns a description of the identity.
no setterinherited
-
disposed
→ bool
-
Indicates whether the ILifecycle implementation has been disposed.
no setterinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
id
→ String
-
Returns a unique identifier for the identity.
no setterinherited
-
manager
→ IResourceManager?
-
gets the resource manager that manages this resource
no setter
-
name
→ String
-
Returns a human-readable name for the identity.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
uId
→ String
-
Returns a unique identifier that is guaranteed to be globally unique.
no setterinherited