NetworkStreamConfig class abstract
Base class for all network stream configurations.
- Implemented types
Constructors
- NetworkStreamConfig({required String name, required int channels, required double sampleRate, required StreamDataType dataType})
Properties
- channels → int
-
Number of channels in the stream.
final
- dataType → StreamDataType
-
Data type of the stream.
This is a StreamDataType enum value.
final
- description → String?
-
Returns a description of the identity.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Returns a unique identifier for the identity.
no setterinherited
- name → String
-
Human-readable name for the stream.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleRate → double
-
Sample rate of the stream.
final
Methods
-
copyWith(
{String? id, String? name, int? channelCount, double? sampleRate, StreamDataType? dataType}) → NetworkStreamConfig -
Creates a copy of this configuration with the given fields replaced.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
Converts the object to a map representation for serialization.
override
-
toString(
) → String -
A string representation of this object.
override
-
validate(
{bool throwOnError = false}) → bool -
Validates the configuration.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited