PeerField enum
A field of a PeerDescriptor that a DiscoveryQuery can filter on.
Values
- streamName → const PeerField
-
PeerDescriptor.streamName — String.
- sessionName → const PeerField
-
PeerDescriptor.sessionName — String.
- nodeId → const PeerField
-
PeerDescriptor.nodeId — String.
- nodeUId → const PeerField
-
PeerDescriptor.nodeUId — String.
- nodeRole → const PeerField
-
PeerDescriptor.nodeRole — String.
- capabilities → const PeerField
-
PeerDescriptor.capabilities — a set; MatchOp.contains tests membership, MatchOp.equals compares the comma-joined form.
- randomRoll → const PeerField
-
PeerDescriptor.randomRoll — numeric. Compared numerically.
- startedAt → const PeerField
-
PeerDescriptor.startedAt — ISO-8601, where lexicographic order is chronological order.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited