cleared property
Whether this is the report that the queue is back under half the threshold. Nothing more is reported until it goes over again.
Implementation
final bool cleared;
Whether this is the report that the queue is back under half the threshold. Nothing more is reported until it goes over again.
final bool cleared;