LSLChunk<T> class
A chunk of samples pulled from an inlet, in list-of-samples form.
samples[i] is one frame of channelCount values and timestamps[i] is
its capture timestamp on the sender's clock.
Properties
- errorCode → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
no setter
- isNotEmpty → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleCount → int
-
no setter
-
samples
→ List<
List< T> > -
final
-
timestamps
→ List<
double> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited