LSLChunkPointer class final
Zero-copy result of LSLInlet.pullChunkPointerSync.
The pointers reference the inlet's reusable chunk buffer and are only valid until the next chunk pull on the same inlet (or its destruction).
Constructors
Properties
- channelCount → int
-
final
- dataPointerAddress → int
-
Address of the flat data buffer (
sampleCount * channelCountelements of the stream's native type).final - errorCode → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
no setter
- isNotEmpty → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleCount → int
-
final
- timestampPointerAddress → int
-
Address of the
Float64timestamp buffer (sampleCountelements).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited