LSLPushChunk<T extends NativeType> class
abstract
The base class for chunk push operations, one subclass per channel format.
Data is a flat buffer of sampleCount * channelCount values in
sample-major order. For string streams each element is a pointer to a
NUL-terminated UTF-8 string (see LSLPushChunkString).
Constructors
-
LSLPushChunk(DartLSLPushChunk<
T> _push, DartLSLPushChunkT<T> _pushT, DartLSLPushChunkTn<T> _pushTn, DartLSLPushChunkTP<T> _pushTP, DartLSLPushChunkTNP<T> _pushTNP) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- typedDataName → String
-
The expected TypedData type name, for error messages.
no setter
Methods
-
allocBuffer(
int elements) → Pointer< T> -
Allocates a flat native buffer of
elementsvalues. -
cleanupBuffer(
Pointer< NativeType> buffer, int elements) → void -
Frees any per-element allocations flatListToBuffer made for the first
elementsvalues ofbuffer. -
flatListToBuffer(
Iterable flat, Pointer< NativeType> buffer) → void -
Writes
flat(length = elements) intobufferelement-wise. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pushNow(
lsl_outlet out, Pointer< NativeType> data, int elements) → int -
Pushes
elementsvalues stamped with the current time. -
pushWithTimestamp(
lsl_outlet out, Pointer< NativeType> data, int elements, double timestamp, {bool? pushthrough}) → int -
Pushes
elementsvalues with a singletimestamp(0.0 = now). -
pushWithTimestamps(
lsl_outlet out, Pointer< NativeType> data, int elements, Pointer<Double> timestamps, {bool? pushthrough}) → int -
Pushes
elementsvalues with one timestamp per sample. -
toString(
) → String -
A string representation of this object.
inherited
-
typedDataMatches(
TypedData data) → bool -
Whether
datais the TypedData type matching this channel format. -
typedDataToBuffer(
TypedData src, Pointer< NativeType> buffer, int elements) → void -
Copies
elementsvalues fromsrcintobuffer(memmove).
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited