LSLStreamInfo class
Representation of the lsl_streaminfo_struct_ from the LSL C API.
Constructors
- LSLStreamInfo({String streamName = "DartLSLStream", LSLContentType streamType = LSLContentType.eeg, int channelCount = 16, double sampleRate = 250.0, LSLChannelFormat channelFormat = LSLChannelFormat.float32, String sourceId = "DartLSL", lsl_streaminfo? streamInfo})
- Creates a new LSLStreamInfo object.
- LSLStreamInfo.fromStreamInfo(lsl_streaminfo streamInfo)
-
Creates a new LSLStreamInfo object from an existing lsl_streaminfo.
factory
- LSLStreamInfo.fromStreamInfoAddr(int address)
-
Creates a new LSLStreamInfo object from an existing stream info address.
/
When constructing inlets, this creates the LSLStreamInfo object based
on an existing stream info address, which can be retrieved from a
stream resolver.
factory
Properties
- channelBytes → int
-
Number of bytes occupied by one channel value (0 for string streams,
whose values are variable-length).
no setter
- channelCount → int
-
final
- channelFormat → LSLChannelFormat
-
final
- created → bool
-
Whether the object has been created.
no setterinherited
- createdAt → double
-
LSL.localClock time at which the stream was created on the sending
machine (0.0 for a stream info that has not been served by an outlet).
no setter
- destroyed → bool
-
Whether the object has been destroyed.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setteroverride
- hostname → String?
-
no setter
- protocolVersion → int
-
The LSL protocol version the stream info was created with (e.g. 110
for 1.10).
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleBytes → int
-
Number of bytes occupied by one sample (
channelBytes * channelCount; 0 for string streams).no setter - sampleRate → double
-
final
- sessionId → String
-
The session ID the stream belongs to (
'default'unless configured via LSLApiConfig.sessionId); resolvers only see streams sharing their own session ID.no setter - sourceId → String
-
final
- streamInfo → lsl_streaminfo
-
The Pointer to the underlying lsl_streaminfo_struct_.
no setter
- streamName → String
-
final
- streamType → LSLContentType
-
final
- uid → String?
-
no setter
Methods
-
addAlloc(
Pointer< NativeType> arg) → void -
Adds a pointer to the list of allocated pointers.
inherited
-
addAllocList(
List< Pointer< args) → voidNativeType> > -
Adds a list of pointers to the list of allocated pointers.
inherited
-
copy(
) → LSLStreamInfoWithMetadata - Creates an independent deep copy of this stream info (including its description). The copy owns its native handle: call destroy on it when done; it stays valid after this object is destroyed.
-
create(
) → LSLStreamInfo - Creates the stream info object, allocates memory, etc.
-
destroy(
) → void - Destroys the object.
-
freeArgs(
) → void -
Frees all allocated pointers.
inherited
-
fromXml(
String xml) → LSLStreamInfoWithMetadata -
matchesQuery(
String query) → bool -
Whether this stream info matches the XPath 1.0
query(the same predicate syntax as LSL.resolveStreamsByPredicate, e.g."name='EEG' and type='EEG'"). -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resetUid(
) → String - Resets the stream info's UID. @note This is not a common operation and should be used with caution. This retuns the new UID as a string.
-
toString(
) → String -
A string representation of this object.
override
-
toXml(
) → String
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override