createdAt property
double
get
createdAt
LSL.localClock time at which the stream was created on the sending machine (0.0 for a stream info that has not been served by an outlet).
Implementation
double get createdAt => lsl_get_created_at(_infoBang);